@@ -1,3 +1,4 @@
+from keras.src.backend.common.name_scope import name_scope
 from keras.src.backend.numpy import core
 from keras.src.backend.numpy import image
 from keras.src.backend.numpy import linalg
@@ -5,6 +6,8 @@ from keras.src.backend.numpy import math
 from keras.src.backend.numpy import nn
 from keras.src.backend.numpy import numpy
 from keras.src.backend.numpy import random
+from keras.src.backend.numpy.core import IS_THREAD_SAFE
+from keras.src.backend.numpy.core import SUPPORTS_RAGGED_TENSORS
 from keras.src.backend.numpy.core import SUPPORTS_SPARSE_TENSORS
 from keras.src.backend.numpy.core import Variable
 from keras.src.backend.numpy.core import cast
@@ -12,7 +15,9 @@ from keras.src.backend.numpy.core import compute_output_spec
 from keras.src.backend.numpy.core import cond
 from keras.src.backend.numpy.core import convert_to_numpy
 from keras.src.backend.numpy.core import convert_to_tensor
+from keras.src.backend.numpy.core import device_scope
 from keras.src.backend.numpy.core import is_tensor
+from keras.src.backend.numpy.core import random_seed_dtype
 from keras.src.backend.numpy.core import shape
 from keras.src.backend.numpy.core import vectorized_map
 from keras.src.backend.numpy.rnn import cudnn_ok
