@@ -7,6 +7,8 @@ from keras.src.backend.tensorflow import nn
 from keras.src.backend.tensorflow import numpy
 from keras.src.backend.tensorflow import random
 from keras.src.backend.tensorflow import tensorboard
+from keras.src.backend.tensorflow.core import IS_THREAD_SAFE
+from keras.src.backend.tensorflow.core import SUPPORTS_RAGGED_TENSORS
 from keras.src.backend.tensorflow.core import SUPPORTS_SPARSE_TENSORS
 from keras.src.backend.tensorflow.core import Variable
 from keras.src.backend.tensorflow.core import cast
@@ -17,6 +19,7 @@ from keras.src.backend.tensorflow.core import convert_to_tensor
 from keras.src.backend.tensorflow.core import device_scope
 from keras.src.backend.tensorflow.core import is_tensor
 from keras.src.backend.tensorflow.core import name_scope
+from keras.src.backend.tensorflow.core import random_seed_dtype
 from keras.src.backend.tensorflow.core import scatter
 from keras.src.backend.tensorflow.core import shape
 from keras.src.backend.tensorflow.core import stop_gradient
