@@ -7,6 +7,14 @@ from keras.src.utils.module_utils import tensorflow as tf
 
 
 def get_input_signature(model):
+    """Get input signature for model export.
+
+    Args:
+        model: A Keras Model instance.
+
+    Returns:
+        Input signature suitable for model export (always a tuple or list).
+    """
     if not isinstance(model, models.Model):
         raise TypeError(
             "The model must be a `keras.Model`. "
@@ -17,13 +25,20 @@ def get_input_signature(model):
             "The model provided has not yet been built. It must be built "
             "before export."
         )
+
     if isinstance(model, models.Functional):
+        # Functional models expect a single positional argument `inputs`
+        # containing the full nested input structure. We keep the
+        # original behavior of returning a single-element list that
+        # wraps the mapped structure so that downstream exporters
+        # build a tf.function with one positional argument.
         input_signature = [
             tree.map_structure(make_input_spec, model._inputs_struct)
         ]
     elif isinstance(model, models.Sequential):
         input_signature = tree.map_structure(make_input_spec, model.inputs)
     else:
+        # Subclassed models: rely on recorded shapes from the first call.
         input_signature = _infer_input_signature_from_model(model)
         if not input_signature or not model._called:
             raise ValueError(
@@ -60,6 +75,7 @@ def _infer_input_signature_from_model(model):
                 f"Unsupported type {type(structure)} for {structure}"
             )
 
+    # Always return a flat list preserving the order of shapes_dict values
     return [_make_input_spec(value) for value in shapes_dict.values()]
 
 
@@ -86,13 +102,34 @@ def make_input_spec(x):
     return input_spec
 
 
-def make_tf_tensor_spec(x):
+def make_tf_tensor_spec(x, dynamic_batch=True):
+    """Create a TensorSpec from various input types.
+
+    Args:
+        x: Input to convert (tf.TensorSpec, KerasTensor, or backend tensor).
+        dynamic_batch: If True, set the batch dimension to None.
+
+    Returns:
+        A tf.TensorSpec instance.
+    """
     if isinstance(x, tf.TensorSpec):
         tensor_spec = x
+        # Adjust batch dimension if needed
+        if dynamic_batch and len(tensor_spec.shape) > 0:
+            shape = tuple(
+                None if i == 0 else s for i, s in enumerate(tensor_spec.shape)
+            )
+            tensor_spec = tf.TensorSpec(
+                shape, dtype=tensor_spec.dtype, name=tensor_spec.name
+            )
     else:
         input_spec = make_input_spec(x)
+        shape = input_spec.shape
+        # Adjust batch dimension if needed and shape is not None
+        if dynamic_batch and shape is not None and len(shape) > 0:
+            shape = tuple(None if i == 0 else s for i, s in enumerate(shape))
         tensor_spec = tf.TensorSpec(
-            input_spec.shape, dtype=input_spec.dtype, name=input_spec.name
+            shape, dtype=input_spec.dtype, name=input_spec.name
         )
     return tensor_spec
 
