@@ -109,22 +109,26 @@ class Bidirectional(Layer):
         # Recreate the forward layer from the original layer config, so that it
         # will not carry over any state from the layer.
         config = serialization_lib.serialize_keras_object(layer)
-        config["config"]["name"] = "forward_" + utils.removeprefix(
-            layer.name, "forward_"
+        config["config"]["name"] = (
+            f"forward_{utils.removeprefix(layer.name, 'forward_')}"
         )
         self.forward_layer = serialization_lib.deserialize_keras_object(config)
 
         if backward_layer is None:
             config = serialization_lib.serialize_keras_object(layer)
             config["config"]["go_backwards"] = True
-            config["config"]["name"] = "backward_" + utils.removeprefix(
-                layer.name, "backward_"
+            config["config"]["name"] = (
+                f"backward_{utils.removeprefix(layer.name, 'backward_')}"
             )
             self.backward_layer = serialization_lib.deserialize_keras_object(
                 config
             )
         else:
             self.backward_layer = backward_layer
+        # Keep the use_cudnn attribute if defined (not serialized).
+        if hasattr(layer, "use_cudnn"):
+            self.forward_layer.use_cudnn = layer.use_cudnn
+            self.backward_layer.use_cudnn = layer.use_cudnn
         self._verify_layer_config()
 
         def force_zero_output_for_mask(layer):
