@@ -22,7 +22,7 @@ class Operation(KerasSaveable):
         if not isinstance(name, str) or "/" in name:
             raise ValueError(
                 "Argument `name` must be a string and "
-                "cannot contain character `/`. "
+                f"cannot contain character `/`. "
                 f"Received: name={name} (of type {type(name)})"
             )
         self.name = name
@@ -129,15 +129,55 @@ class Operation(KerasSaveable):
                 vars(instance)["_object__state"] = nnx.object.ObjectState()
 
         # Generate a config to be returned by default by `get_config()`.
-        arg_names = inspect.getfullargspec(cls.__init__).args
-        kwargs.update(dict(zip(arg_names[1 : len(args) + 1], args)))
+        auto_config = True
+
+        signature = inspect.signature(cls.__init__)
+        argspec = inspect.getfullargspec(cls.__init__)
+
+        try:
+            bound_parameters = signature.bind(None, *args, **kwargs)
+        except TypeError:
+            # Raised by signature.bind when the supplied args and kwargs
+            # do not match the signature.
+            auto_config = False
+
+        if auto_config and any(
+            [
+                param.kind == inspect.Parameter.POSITIONAL_ONLY
+                for name, param in signature.parameters.items()
+                if name != argspec.args[0]
+            ]
+        ):
+            # cls.__init__ takes positional only arguments, which
+            # cannot be restored via cls(**config)
+            auto_config = False
+            # Create variable to show appropriate warning in get_config.
+            instance._auto_config_error_args = True
+
+        if auto_config:
+            # Include default values in the config.
+            bound_parameters.apply_defaults()
+            # Extract all arguments as a dictionary.
+            kwargs = bound_parameters.arguments
+            # Expand variable kwargs argument.
+            kwargs |= kwargs.pop(argspec.varkw, {})
+            # Remove first positional argument, self.
+            kwargs.pop(argspec.args[0])
+            # Remove argument "name", as it is provided by get_config.
+            kwargs.pop("name", None)
+            if argspec.varargs is not None:
+                # Varargs cannot be meaningfully converted to a dictionary.
+                varargs = kwargs.pop(argspec.varargs)
+                if len(varargs) > 0:
+                    auto_config = False
+                    # Store variable to show appropriate warning in get_config.
+                    instance._auto_config_error_args = True
 
         # For safety, we only rely on auto-configs for a small set of
         # serializable types.
         supported_types = (str, int, float, bool, type(None))
         try:
             flat_arg_values = tree.flatten(kwargs)
-            auto_config = True
             for value in flat_arg_values:
                 if not isinstance(value, supported_types):
                     auto_config = False
@@ -192,30 +232,52 @@ class Operation(KerasSaveable):
                 config.pop("name", None)
             return config
         else:
-            raise NotImplementedError(
-                textwrap.dedent(
-                    f"""
-        Object {self.__class__.__name__} was created by passing
-        non-serializable argument values in `__init__()`,
-        and therefore the object must override `get_config()` in
-        order to be serializable. Please implement `get_config()`.
+            example_str = """
+            class CustomLayer(keras.layers.Layer):
+                def __init__(self, arg1, arg2, **kwargs):
+                    super().__init__(**kwargs)
+                    self.arg1 = arg1
+                    self.arg2 = arg2
 
-        Example:
+                def get_config(self):
+                    config = super().get_config()
+                    config.update({
+                        "arg1": self.arg1,
+                        "arg2": self.arg2,
+                    })
+                    return config
+            """
+            if getattr(self, "_auto_config_error_args", False):
+                raise NotImplementedError(
+                    textwrap.dedent(
+                        f"""
+            Object {self.__class__.__name__} was created by passing
+            positional only or variadic positional arguments (e.g.,
+            `*args`) to `__init__()`, which is not supported by the
+            automatic config generation. Please remove all positional
+            only and variadic arguments from `__init__()`
+            or override `get_config()` and `from_config()` to make
+            the object serializatble.
 
-        class CustomLayer(keras.layers.Layer):
-            def __init__(self, arg1, arg2, **kwargs):
-                super().__init__(**kwargs)
-                self.arg1 = arg1
-                self.arg2 = arg2
+            Example:
 
-            def get_config(self):
-                config = super().get_config()
-                config.update({"arg1": self.arg1,
-                    "arg2": self.arg2,
-                })
-                return config"""
+            {example_str}"""
+                    )
+                )
+            else:
+                raise NotImplementedError(
+                    textwrap.dedent(
+                        f"""
+            Object {self.__class__.__name__} was created by passing
+            non-serializable argument values in `__init__()`,
+            and therefore the object must override `get_config()` in
+            order to be serializable. Please implement `get_config()`.
+
+            Example:
+
+            {example_str}"""
+                    )
                 )
-            )
 
     @classmethod
     def from_config(cls, config):
