@@ -15,7 +15,7 @@ class AdamW(adam.Adam):
 
     According to
     [Kingma et al., 2014](http://arxiv.org/abs/1412.6980),
-    the underying Adam method is "*computationally
+    the underlying Adam method is "*computationally
     efficient, has little memory requirement, invariant to diagonal rescaling of
     gradients, and is well suited for problems that are large in terms of
     data/parameters*".
