@@ -310,13 +310,12 @@ class BaseOptimizer(KerasSaveable):
         """
         name = name or "var"
         if hasattr(reference_variable, "path"):
-            name = reference_variable.path.replace("/", "_") + "_" + name
+            name = f"{reference_variable.path.replace('/', '_')}_{name}"
         else:
-            name = (
+            sanitised_ref_name = (
                 str(reference_variable.name).replace("/", "_").replace(":", "_")
-                + "_"
-                + name
             )
+            name = f"{sanitised_ref_name}_{name}"
         return self.add_variable(
             shape=reference_variable.shape,
             initializer=initializer,
@@ -632,6 +631,20 @@ class BaseOptimizer(KerasSaveable):
             g_acc.assign(n_g_acc)
 
     def stateless_apply(self, optimizer_variables, grads, trainable_variables):
+        """Stateless version of `apply` that returns modified variables.
+
+        Args:
+            optimizer_variables: list of tensors containing the current values
+                for the optimizer variables. These are native tensors and not
+                `keras.Variable`s.
+            grads: list of gradients to apply.
+            trainable_variables: list of tensors containing the current values
+                for the model variables. These are native tensors and not
+                `keras.Variable`s.
+
+        Returns: A tuple containing two list of tensors, the updated
+            `trainable_variables` and the updated `optimizer_variables`.
+        """
         self._check_super_called()
 
         if not self.built:
@@ -970,10 +983,15 @@ class BaseOptimizer(KerasSaveable):
             ):
                 if average is not None:
                     not_first_step = ops.not_equal(self.iterations, 0)
-                    momentum = (
-                        ops.cast(not_first_step, var.dtype) * self.ema_momentum
+                    momentum = ops.multiply(
+                        ops.cast(not_first_step, var.dtype), self.ema_momentum
+                    )
+                    average.assign(
+                        ops.add(
+                            ops.multiply(momentum, average),
+                            ops.multiply(ops.subtract(1, momentum), var),
+                        )
                     )
-                    average.assign(momentum * average + (1 - momentum) * var)
 
     def _overwrite_model_variables_with_average_value(
         self, trainable_variables
