@@ -148,6 +148,7 @@ class CompileMetrics(metrics_module.Metric):
         self.built = False
         self.name = "compile_metrics"
         self.output_names = output_names
+        self._resolved_output_names = None
 
     @property
     def metrics(self):
@@ -175,10 +176,16 @@ class CompileMetrics(metrics_module.Metric):
 
     def build(self, y_true, y_pred):
         num_outputs = 1  # default
-        if self.output_names:
+        # Resolve output names. If y_pred is a dict, prefer its keys.
+        if isinstance(y_pred, dict):
+            keys = sorted(list(y_pred.keys()))
+            if self.output_names and set(self.output_names) == set(keys):
+                # If there is a perfect match, use the user-provided order.
+                output_names = self.output_names
+            else:
+                output_names = keys
+        elif self.output_names:
             output_names = self.output_names
-        elif isinstance(y_pred, dict):
-            output_names = sorted(list(y_pred.keys()))
         elif isinstance(y_pred, (list, tuple)):
             num_outputs = len(y_pred)
             if all(hasattr(x, "_keras_history") for x in y_pred):
@@ -187,6 +194,7 @@ class CompileMetrics(metrics_module.Metric):
                 output_names = None
         else:
             output_names = None
+        self._resolved_output_names = output_names
         if output_names:
             num_outputs = len(output_names)
 
@@ -316,9 +324,10 @@ class CompileMetrics(metrics_module.Metric):
         return flat_metrics
 
     def _flatten_y(self, y):
-        if isinstance(y, dict) and self.output_names:
+        names = self._resolved_output_names
+        if isinstance(y, dict) and names:
             result = []
-            for name in self.output_names:
+            for name in names:
                 if name in y:
                     result.append(y[name])
             return result
@@ -659,7 +668,7 @@ class CompileLoss(losses_module.Loss):
         # Add `Mean` metric to the tracker for each loss.
         if len(self._flat_losses) > 1:
             for _loss in self._flat_losses:
-                name = _loss.name + "_loss"
+                name = f"{_loss.name}_loss"
                 self._tracker.add_to_store(
                     "metrics", metrics_module.Mean(name=name)
                 )
@@ -690,17 +699,34 @@ class CompileLoss(losses_module.Loss):
             return self.call(y_true, y_pred, sample_weight)
 
     def call(self, y_true, y_pred, sample_weight=None):
+        def resolve_path(path, object):
+            for _path in path:
+                object = object[_path]
+            return object
+
         if not tree.is_nested(y_true) and not tree.is_nested(y_pred):
             # Fast path: single output case / no loss-tracking metric.
             if not self.built:
                 self.build(y_true, y_pred)
-            _, loss_fn, loss_weight, _ = self._flat_losses[0]
-            loss_value = ops.cast(
-                loss_fn(y_true, y_pred, sample_weight), dtype=self.dtype
-            )
-            if loss_weight is not None:
-                loss_value = ops.multiply(loss_value, loss_weight)
-            return loss_value
+            # Although we are in the fast path, we still need to iterate
+            # through the losses to prevent the torch compiler from failing.
+            loss_values = []
+            for path, loss_fn, loss_weight, _ in self._flat_losses:
+                y_t, y_p = (
+                    resolve_path(path, y_true),
+                    resolve_path(path, y_pred),
+                )
+                if sample_weight is not None and tree.is_nested(sample_weight):
+                    _sample_weight = resolve_path(path, sample_weight)
+                else:
+                    _sample_weight = sample_weight
+                value = ops.cast(
+                    loss_fn(y_t, y_p, _sample_weight), dtype=self.dtype
+                )
+                if loss_weight is not None:
+                    value = ops.multiply(value, loss_weight)
+                loss_values.append(value)
+            return loss_values[0]
 
         try:
             tree.assert_same_structure(y_pred, y_true)
@@ -779,11 +805,6 @@ class CompileLoss(losses_module.Loss):
         # Iterate all losses in flat form.
         loss_values = []
 
-        def resolve_path(path, object):
-            for _path in path:
-                object = object[_path]
-            return object
-
         for (path, loss_fn, loss_weight, _), metric in zip(
             self._flat_losses, metrics
         ):
