@@ -8,6 +8,9 @@ from keras.src.trainers.data_adapters.array_data_adapter import ArrayDataAdapter
 from keras.src.trainers.data_adapters.generator_data_adapter import (
     GeneratorDataAdapter,
 )
+from keras.src.trainers.data_adapters.grain_dataset_adapter import (
+    GrainDatasetAdapter,
+)
 from keras.src.trainers.data_adapters.py_dataset_adapter import PyDatasetAdapter
 from keras.src.trainers.data_adapters.tf_dataset_adapter import TFDatasetAdapter
 from keras.src.trainers.data_adapters.torch_data_loader_adapter import (
@@ -28,16 +31,20 @@ def get_data_adapter(
     if isinstance(x, data_adapter.DataAdapter):
         return x
 
-    # Check for multi-process/worker distribution. Since only tf.dataset
-    # is supported at the moment, we will raise error if the inputs fail
-    # the type check
+    # Check for multi-process/worker distribution.
     distribution = distribution_lib.distribution()
-    if getattr(distribution, "_is_multi_process", False) and not is_tf_dataset(
-        x
+    if (
+        distribution is not None
+        and getattr(distribution, "_is_multi_process", False)
+        and getattr(distribution, "auto_shard_dataset", False)
+        and not is_tf_dataset(x)
     ):
         raise ValueError(
-            "When using multi-worker distribution, the data must be provided "
-            f"as a `tf.data.Dataset` instance. Received: type(x)={type(x)}."
+            "When using a multi-worker distribution with auto-sharding enabled, "
+            "the data must be provided as a `tf.data.Dataset` instance. "
+            f"Received: type(x)={type(x)}. "
+            "If the dataset is already sharded across workers, then set "
+            "`distribution.auto_shard_dataset = False`."
         )
 
     if array_data_adapter.can_convert_arrays((x, y, sample_weight)):
@@ -93,7 +100,12 @@ def get_data_adapter(
         if class_weight is not None:
             raise ValueError(
                 "Argument `class_weight` is not supported for torch "
-                f"DataLoader inputs. Received: class_weight={class_weight}"
+                f"DataLoader inputs. You can modify your `__getitem__ ` method"
+                " to return input tensor, label and class_weight. "
+                "Alternatively, use a custom training loop. See the User Guide "
+                "https://keras.io/guides/custom_train_step_in_torch/"
+                "#supporting-sampleweight-amp-classweight for more details. "
+                f"Received: class_weight={class_weight}"
             )
         return TorchDataLoaderAdapter(x)
         # TODO: should we warn or not?
@@ -102,6 +114,32 @@ def get_data_adapter(
         #     "data `x` was provided as a torch DataLoader. The DataLoader "
         #     "is expected to already be shuffled."
         # )
+    elif is_grain_dataset(x):
+        if y is not None:
+            raise_unsupported_arg(
+                "y", "the targets", "grain.Dataset and grain.DataLoader"
+            )
+        if sample_weight is not None:
+            raise_unsupported_arg(
+                "sample_weights",
+                "the sample weights",
+                "grain.Dataset and grain.DataLoader",
+            )
+        if class_weight is not None:
+            raise ValueError(
+                "Argument `class_weight` is not supported for grain.Dataset "
+                f"and grain.DataLoader inputs. You can modify your "
+                "`__getitem__ ` method to return input tensor, label and "
+                "class_weight. "
+                f"Received: class_weight={class_weight}"
+            )
+        return GrainDatasetAdapter(x)
+        # TODO: should we warn or not?
+        # warnings.warn(
+        #     "`shuffle=True` was passed, but will be ignored since the "
+        #     "data `x` was provided as a grain dataset. The grain dataset "
+        #     "is expected to already be shuffled."
+        # )
     elif isinstance(x, types.GeneratorType):
         if y is not None:
             raise_unsupported_arg("y", "the targets", "PyDataset")
@@ -153,3 +191,15 @@ def is_torch_dataloader(x):
             ):
                 return True
     return False
+
+
+def is_grain_dataset(x):
+    if hasattr(x, "__class__"):
+        for parent in x.__class__.__mro__:
+            if parent.__name__ in (
+                "MapDataset",
+                "IterDataset",
+                "DataLoader",
+            ) and "grain" in str(parent.__module__):
+                return True
+    return False
