@@ -175,12 +175,24 @@ def save_img(path, x, data_format=None, file_format=None, scale=True, **kwargs):
         **kwargs: Additional keyword arguments passed to `PIL.Image.save()`.
     """
     data_format = backend.standardize_data_format(data_format)
+
+    # Infer format from path if not explicitly provided
+    if file_format is None and isinstance(path, (str, pathlib.Path)):
+        file_format = pathlib.Path(path).suffix[1:].lower()
+
+    # Normalize jpg → jpeg for Pillow compatibility
+    if file_format and file_format.lower() == "jpg":
+        file_format = "jpeg"
+
     img = array_to_img(x, data_format=data_format, scale=scale)
-    if img.mode == "RGBA" and (file_format == "jpg" or file_format == "jpeg"):
+
+    # Handle RGBA → RGB conversion for JPEG
+    if img.mode == "RGBA" and file_format == "jpeg":
         warnings.warn(
-            "The JPG format does not support RGBA images, converting to RGB."
+            "The JPEG format does not support RGBA images, converting to RGB."
         )
         img = img.convert("RGB")
+
     img.save(path, format=file_format, **kwargs)
 
 
